package WebGUI::i18n::German::Asset_Thingy;
use utf8;
our $I18N = {
  'Creating column headers' => {
    'lastUpdated' => '1288983254',
    'message' => 'Erstelle Spaltenüberschriften'
  },
  'Return to %s' => {
    'lastUpdated' => '1288983291',
    'message' => 'Zurück zu %s.'
  },
  'Writing data' => {
    'lastUpdated' => '1288983232',
    'message' => 'Schreibe Daten'
  },
  'add field label' => {
    'lastUpdated' => '1227002067',
    'message' => 'Feld hinzufügen'
  },
  'add label' => {
    'lastUpdated' => '1227001907',
    'message' => 'Hinzufügen'
  },
  'add other thing label' => {
    'lastUpdated' => '1227001926',
    'message' => 'Weitere Tabelle hinzufügen'
  },
  'add thing label' => {
    'lastUpdated' => '1227001889',
    'message' => 'Tabelle hinzufügen'
  },
  'addThing_url' => {
    'lastUpdated' => '1227002010',
    'message' => 'Diese URL verweist zum Hinzufügen einer neuen Tabelle'
  },
  'add_url' => {
    'lastUpdated' => '1227002250',
    'message' => 'URL zum Bildschirm Datensatz in diese Tabelle einfügen.'
  },
  'after save description' => {
    'lastUpdated' => '1238879974',
    'message' => 'Der Bildschirm, der nach der Sicherung dieser Tabelle angezeigt wird.'
  },
  'after save label' => {
    'lastUpdated' => '1227002054',
    'message' => 'Nach der Sicherung'
  },
  'assetName' => {
    'lastUpdated' => '1227012451',
    'message' => 'Thingy'
  },
  'back to thingy default view' => {
    'lastUpdated' => '1240471399',
    'message' => 'Zurück'
  },
  'cache timeout' => {
    'lastUpdated' => '1244363381',
    'message' => 'Cache Timeout'
  },
  'cache timeout help' => {
    'lastUpdated' => '1244363512',
    'message' => 'Da alle Benutzer dieses Asset in gleicher Form sehen, kann es, um die Performance zu erhöhen, für längere Zeit ins Cache aufgenommen werden. Wie lange soll es aufgenommen werden?'
  },
  'canEditThings' => {
    'lastUpdated' => '1241126984',
    'message' => '"wahr" wenn der aktuelle Benutzer die Tabellen in diesem Asset sehen kann.'
  },
  'canView' => {
    'lastUpdated' => '1238880059',
    'message' => 'Eine Bedingung, die angibt ob der aktuelle Benutzer die Berechtigung hat, diese Tabelle anzuschauen. '
  },
  'check duplicates label' => {
    'lastUpdated' => '1240824005',
    'message' => 'Auf Duplikate überprüfen?'
  },
  'default save button label' => {
    'lastUpdated' => '1227001838',
    'message' => 'Sichern'
  },
  'default thing label' => {
    'lastUpdated' => '1227001824',
    'message' => 'Standardtabelle'
  },
  'default value description' => {
    'lastUpdated' => '1236680887',
    'message' => 'Geben Sie ggf. einen Standardwert für dieses Feld ein.
Wenn Sie einen Hash mit möglichen Werten definiert haben, dann soll der Standardwert ein Schlüssel dieses Hashes sein und kein Wert.
Bei "Ja/Nein" Feldern, geben Sie "yes" für "Ja" und "no" für "Nein" ein.'
  },
  'default value label' => {
    'lastUpdated' => '1227001811',
    'message' => 'Standardwert'
  },
  'default value subtext' => {
    'lastUpdated' => '1238879666',
    'message' => 'Eine Eingabe pro Zeile'
  },
  'default view description' => {
    'lastUpdated' => '1239402484',
    'message' => 'Die Standardausgabe für diese Tabelle. Das kann entweder eine Suchmaske mit Ergebebnissen oder auch den Bildschirm für das Hinzufügen eines Datensatzes sein.'
  },
  'default view label' => {
    'lastUpdated' => '1227001796',
    'message' => 'Standardanzeige'
  },
  'delete label' => {
    'lastUpdated' => '1227001205',
    'message' => 'Löschen'
  },
  'delete thing data warning' => {
    'lastUpdated' => '1255430082',
    'message' => 'Möchten Sie diesen Eintrag wirklich löschen? Die Aktion ist nicht versioniert und kann nicht widerrufen werden.'
  },
  'delete thing warning' => {
    'lastUpdated' => '1240997756',
    'message' => 'Möchten Sie diese Tabelle und alle Daten wirklich löschen? Dieser Vorgang ist entgültig!'
  },
  'delete_confirm' => {
    'lastUpdated' => '1245621965',
    'message' => 'Dieses enthält eine "onclick"-Eigenschaft für den Link "Löschen", die eine Javascript Bestätigung hinzufügt.'
  },
  'delete_url' => {
    'lastUpdated' => '1246484726',
    'message' => 'Url zum Löschen der aktuellen Tabelle'
  },
  'display label' => {
    'lastUpdated' => '1227001779',
    'message' => 'Anzeige'
  },
  'displayInSearchFields_fieldId' => {
    'lastUpdated' => '1247905071',
    'message' => 'Die ID dieses Feldes.'
  },
  'displayInSearchFields_label' => {
    'lastUpdated' => '1247905092',
    'message' => 'Label dieses Feldes'
  },
  'displayInSearchFields_loop' => {
    'lastUpdated' => '1250932896',
    'message' => 'Eine Schleife mit den Feldern, die in einem Suchergebnis angeziegt werden.'
  },
  'displayInSearchFields_orderByUrl' => {
    'lastUpdated' => '1250933333',
    'message' => 'Url zum Sortieren der Suchergebnisse nach diesem Feld.'
  },
  'duplicates label' => {
    'lastUpdated' => '1240997627',
    'message' => 'Was soll mit Doppelteinträgen passieren?'
  },
  'edit instructions description' => {
    'lastUpdated' => '1247905045',
    'message' => 'Hinweise beim Bearbeiten oder Hinzufügen einer Tabelle.'
  },
  'edit instructions label' => {
    'lastUpdated' => '1247904898',
    'message' => 'Anweisungen'
  },
  'edit label' => {
    'lastUpdated' => '1227001701',
    'message' => 'Bearbeiten'
  },
  'edit screen tab label' => {
    'lastUpdated' => '1247904801',
    'message' => 'Bearbeiten'
  },
  'edit screen title description' => {
    'lastUpdated' => '1247905133',
    'message' => 'Titel des Bearbeitungsbildschirms'
  },
  'edit screen title label' => {
    'lastUpdated' => '1240823944',
    'message' => 'Bearbeitungsmodus'
  },
  'edit template description' => {
    'lastUpdated' => '1250933003',
    'message' => 'Die Bearbeitungsvorlage wird verwendet um den Ansichtsbildschirm dieser Tabelle zu gestalten. '
  },
  'edit template label' => {
    'lastUpdated' => '1247904859',
    'message' => 'Bearbeitungsvorlage'
  },
  'edit thing template label' => {
    'lastUpdated' => '1247905363',
    'message' => 'Vorlage Tabellenbearbeitung '
  },
  'edit thing title' => {
    'lastUpdated' => '1227001427',
    'message' => 'Tabelle bearbeiten'
  },
  'editInstructions' => {
    'lastUpdated' => '1240997097',
    'message' => 'Änderungsanweisungen für diese Tabelle'
  },
  'editScreenTitle' => {
    'lastUpdated' => '1238256717',
    'message' => 'Ändern'
  },
  'edit_url' => {
    'lastUpdated' => '1244363623',
    'message' => 'URL zum Bearbeiten dieser Tabelle '
  },
  'error_loop' => {
    'lastUpdated' => '1247905427',
    'message' => 'Eine Schleife mit Fehlerinformation wie z.B. ob jemand erforderliche Information nicht ausgefüllt hat.'
  },
  'error_message' => {
    'lastUpdated' => '1245622005',
    'message' => 'Eine Fehlermeldung, die Angibt, was ein Benutzer ggf. falsch gemacht hat.'
  },
  'export label' => {
    'lastUpdated' => '1240471950',
    'message' => 'Export'
  },
  'export metadata description' => {
    'lastUpdated' => '1250942782',
    'message' => 'Soll die Export-Funktion auch Metadaten wie thingDataId,  lastUpdated, ipAdress etc. enthalten?'
  },
  'export metadata label' => {
    'lastUpdated' => '1245622375',
    'message' => 'Metadaten exportieren?'
  },
  'export_url' => {
    'lastUpdated' => '1249047162',
    'message' => 'URL zum Exportieren von Suchergebnissen in eine csv-Datei.'
  },
  'extras description' => {
    'lastUpdated' => '1250933403',
    'message' => 'Hier können Sie extra Eigenschaften zu diesem Feld hinzufügen, wie z.B.: \'class="super"\''
  },
  'extras label' => {
    'lastUpdated' => '1247904814',
    'message' => 'Extras'
  },
  'field in other thing label' => {
    'lastUpdated' => '1240477757',
    'message' => 'Feld in anderer Tabelle'
  },
  'field label description' => {
    'lastUpdated' => '1250933031',
    'message' => 'Das Label für dieses Feld.'
  },
  'field label label' => {
    'lastUpdated' => '1247904834',
    'message' => 'Label'
  },
  'field status description' => {
    'lastUpdated' => '1250933247',
    'message' => 'Verborgene (hidden) Felder sind für den Benutzer nicht sichtbar. 
Sichtbare (visible) Felder können gesehen aber nicht geändert werden. 
Bearbeitbare Felder können bearbeitet werden.
Erforderliche Felder müssen bearbeitet werden.
Wenn Sie "verborgen" oder "sichtbar" wählen, geben Sie bitte auch einen Standardwert an.'
  },
  'field status label' => {
    'lastUpdated' => '1246484736',
    'message' => 'Status'
  },
  'field type description' => {
    'lastUpdated' => '1247905236',
    'message' => 'Wählen Sie den Typ des Formularelements für dieses Feld. Dieser ist auch maßgeblich bei der Überprüfung der Dateneingabe.'
  },
  'field type label' => {
    'lastUpdated' => '1240477853',
    'message' => 'Feldtyp'
  },
  'field_form' => {
    'lastUpdated' => '1244363652',
    'message' => 'Formularelement für dieses Feld.'
  },
  'field_id' => {
    'lastUpdated' => '1240487459',
    'message' => 'Die ID dieses Felds'
  },
  'field_isHidden' => {
    'lastUpdated' => '1245622042',
    'message' => 'Gibt an, ob das Feld verborgen sein soll.'
  },
  'field_isRequired' => {
    'lastUpdated' => '1240997154',
    'message' => 'Eine Bedingung, die angibt, ob eine Eingabe in dieses Feld erforderlich ist.'
  },
  'field_isVisible' => {
    'lastUpdated' => '1245622423',
    'message' => 'Eine Bedingung, die angibt, ob dieses Field sichtbar, aber nicht editierbar sein soll.'
  },
  'field_label' => {
    'lastUpdated' => '1234944683',
    'message' => 'Bezeichnung'
  },
  'field_loop' => {
    'lastUpdated' => '1247905275',
    'message' => 'Eine Schleife mit den sichtbaren Feldern dieser Tabelle'
  },
  'field_name' => {
    'lastUpdated' => '1240487427',
    'message' => 'Name des Formularelements für dieses Feld'
  },
  'field_pretext' => {
    'lastUpdated' => '1240997847',
    'message' => 'Zusatztext vor das Eingabefeld.'
  },
  'field_subtext' => {
    'lastUpdated' => '1246484819',
    'message' => 'Beschreibung des Feldes, damit Benutzer wissen, wie das Feld ausgefüllt werden soll. Sie soll angezeigt werden unter/nach dem Formularfeld.'
  },
  'field_type' => {
    'lastUpdated' => '1245622942',
    'message' => 'Der Typ (Datei, Text, etc.) dieses Feldes'
  },
  'field_url' => {
    'lastUpdated' => '1249047179',
    'message' => 'Eine optionale URL wozu dieses Feld verlinken soll. Das wird z.B. benutzt um zu Feldern in anderen Tabellen zu verlinken.'
  },
  'field_value' => {
    'lastUpdated' => '1236681150',
    'message' => 'Der Wert dieses Feldes'
  },
  'fields label' => {
    'lastUpdated' => '1238256735',
    'message' => 'Felder'
  },
  'fields tab label' => {
    'lastUpdated' => '1244363663',
    'message' => 'Felder'
  },
  'fieldstatus editable label' => {
    'lastUpdated' => '1240582154',
    'message' => 'Änderbar'
  },
  'fieldstatus hidden label' => {
    'lastUpdated' => '1245622438',
    'message' => 'Verborgen'
  },
  'fieldstatus required label' => {
    'lastUpdated' => '1245622451',
    'message' => 'Erforderlich'
  },
  'fieldstatus visible label' => {
    'lastUpdated' => '1245622059',
    'message' => 'Sichtbar'
  },
  'file contains label' => {
    'lastUpdated' => '1240582301',
    'message' => 'File enthält'
  },
  'form_end' => {
    'lastUpdated' => '1240997465',
    'message' => 'Ende des Formulars'
  },
  'form_start' => {
    'lastUpdated' => '1240997480',
    'message' => 'Anfang des Formulars'
  },
  'form_submit' => {
    'lastUpdated' => '1236681187',
    'message' => 'Abschicken'
  },
  'has entered max per user message' => {
    'lastUpdated' => '1240997198',
    'message' => 'Sie haben die für Sie maximale Anzahl der Einträge in dieser Tabelle erreicht'
  },
  'height description' => {
    'lastUpdated' => '1244363747',
    'message' => 'Definieren Sie die Höhe dieses Feldes in Pixel. Nur ausgewertet bei Text- und HTML-Bereichen.'
  },
  'height label' => {
    'lastUpdated' => '1240997448',
    'message' => 'Höhe'
  },
  'height subtext' => {
    'lastUpdated' => '1240997521',
    'message' => 'Optional fur Text-/HTML-area'
  },
  'ignore first line label' => {
    'lastUpdated' => '1240582221',
    'message' => 'Erste Zeile ignorieren?'
  },
  'import file label' => {
    'lastUpdated' => '1240471929',
    'message' => 'Wählen Sie eine Datei zum Importieren'
  },
  'import label' => {
    'lastUpdated' => '1238879704',
    'message' => 'Import'
  },
  'import_url' => {
    'lastUpdated' => '1249047232',
    'message' => 'URL zur csv-Datei, die importiert werden soll.'
  },
  'is required error' => {
    'lastUpdated' => '1236681213',
    'message' => 'ist erforderlich'
  },
  'isCurrent' => {
    'lastUpdated' => '1240478313',
    'message' => 'Eine Bedingung, die angibt, ob mit dieser Tabelle gearbeitet wird.'
  },
  'listOfThings' => {
    'lastUpdated' => '1236681129',
    'message' => 'Eine Schleife mit einer Liste aller Tabellen in diesem Thingy-Objekt'
  },
  'manage things label' => {
    'lastUpdated' => '1227002328',
    'message' => 'Tabellen verwalten'
  },
  'manage_url' => {
    'lastUpdated' => '1240487372',
    'message' => 'URL zur Tabellen-Verwaltung'
  },
  'max entries per user description' => {
    'lastUpdated' => '1240582671',
    'message' => 'Die maximale Anzahl von Einträgen in dieser Tabelle per Benutzer'
  },
  'max entries per user label' => {
    'lastUpdated' => '1238879865',
    'message' => 'Max. Eingaben per Benutzer'
  },
  'name' => {
    'lastUpdated' => '1227001440',
    'message' => 'Bezeichnung der Tabelle'
  },
  'no field values message' => {
    'lastUpdated' => '1240997234',
    'message' => 'Das Feld hat keinen Eintrag'
  },
  'no permission to edit' => {
    'lastUpdated' => '1240997570',
    'message' => 'Sie haben keine Berchtigung diese Tabelle zu ändern.'
  },
  'no permission to search' => {
    'lastUpdated' => '1244363781',
    'message' => 'Sie haben keine Berechtigung diese Tabelle zu durchsuchen.'
  },
  'on add workflow description' => {
    'lastUpdated' => '1251504559',
    'message' => 'Workflow der angestoßen wurde, nachdem diese Tabelle hinzugefügt wurde'
  },
  'on add workflow label' => {
    'lastUpdated' => '1245622091',
    'message' => 'Bei neuem Eintrag'
  },
  'on delete workflow description' => {
    'lastUpdated' => '1251504590',
    'message' => 'Workflow der angestoßen wurde, nachdem diese Tabelle gelöscht wurde'
  },
  'on delete workflow label' => {
    'lastUpdated' => '1245622125',
    'message' => 'Nach löschen eines Eintrags'
  },
  'on edit workflow description' => {
    'lastUpdated' => '1251504611',
    'message' => 'Workflow der angestoßen wurde, nachdem diese Tabelle bearbeitet wurde'
  },
  'on edit workflow label' => {
    'lastUpdated' => '1245622145',
    'message' => 'Bei Änderung'
  },
  'other thing field missing message' => {
    'lastUpdated' => '1245622499',
    'message' => 'Das Feld der anderen Tabelle existiert nicht.'
  },
  'other thing missing message' => {
    'lastUpdated' => '1245622236',
    'message' => 'Das Feld, wozu dieses Feld ein Verweis sein soll, existiert nicht.'
  },
  'overwrite label' => {
    'lastUpdated' => '1240582368',
    'message' => 'überschreiben'
  },
  'owner' => {
    'lastUpdated' => '1254901307',
    'message' => 'Eigentümer'
  },
  'possible values description' => {
    'lastUpdated' => '1251504838',
    'message' => 'Dieses Feld wird für Listentypen (Checkboxen, Auswahllisten, ..) genutzt. Geben Sie die gewünschten Werte zeilenweise ein.<br>Wenn Sie eine abweichende Beschriftung angeben möchten, müssen diese folgendermaßen formatiert werden:<br><span><pre>{<br>  "key1"=&gt;"value1",<br>  "key2"=&gt;"value2",<br>  "key3"=&gt;"value3"<br>  ...<br>}<br></pre></span>Klammern, Anführungszeichen, usw. Ersetzen Sie einfach <span>"key1"/"value1" mit Ihren eignen Schlüsselname/Wert- Paaren<br></span>'
  },
  'possible values label' => {
    'lastUpdated' => '1238256776',
    'message' => 'Zugelassene Werte'
  },
  'possible values subtext' => {
    'lastUpdated' => '1251504853',
    'message' => 'Einer pro Zeile'
  },
  'pretext description' => {
    'lastUpdated' => '1238879830',
    'message' => 'Eine Erweiterung zur Kurzbezeichnung, die als weitere Information zum Feld oberhalb oder vor dem Eingabefeld angezeigt wird.'
  },
  'pretext label' => {
    'lastUpdated' => '1227000900',
    'message' => 'Text vorab'
  },
  'save button label description' => {
    'lastUpdated' => '1240582624',
    'message' => 'Der Text zum Sichern'
  },
  'save button label label' => {
    'lastUpdated' => '1240582546',
    'message' => 'Label zum Knopf "Sichern"'
  },
  'search button label' => {
    'lastUpdated' => '1227001661',
    'message' => 'Suchen'
  },
  'search description description' => {
    'lastUpdated' => '1251504878',
    'message' => 'Beschreibung für die Such-Seite'
  },
  'search description label' => {
    'lastUpdated' => '1236680931',
    'message' => 'Beschreibung'
  },
  'search label' => {
    'lastUpdated' => '1227001649',
    'message' => 'Suchen'
  },
  'search other thing label' => {
    'lastUpdated' => '1240823973',
    'message' => 'In anderer Tabelle suchen'
  },
  'search screen tab label' => {
    'lastUpdated' => '1240582482',
    'message' => 'Suchen'
  },
  'search screen title description' => {
    'lastUpdated' => '1240997264',
    'message' => 'Suchen'
  },
  'search screen title label' => {
    'lastUpdated' => '1236681058',
    'message' => 'Suchen'
  },
  'search template description' => {
    'lastUpdated' => '1251505123',
    'message' => 'Dieses Template zeit die Such-Seite dieser Tabelle an'
  },
  'search template label' => {
    'lastUpdated' => '1240487172',
    'message' => 'Suchvorlage'
  },
  'search thing label' => {
    'lastUpdated' => '1227001639',
    'message' => 'Suchen'
  },
  'search thing template label' => {
    'lastUpdated' => '1245622320',
    'message' => 'Vorlage Tabellensuche'
  },
  'search this thing label' => {
    'lastUpdated' => '1240487257',
    'message' => 'Diese Tabelle durchsuchen'
  },
  'searchDescription' => {
    'lastUpdated' => '1240582452',
    'message' => 'Beschreibung zum Suchbildschirm'
  },
  'searchFields_fieldId' => {
    'lastUpdated' => '1251505152',
    'message' => 'Die fieldId des durchsuchbaren Feldes'
  },
  'searchFields_form' => {
    'lastUpdated' => '1246484932',
    'message' => 'Formelement, entsprechend dem Typ um dieses Feld zu durchsuchen.'
  },
  'searchFields_is__fieldType__' => {
    'lastUpdated' => '1251506075',
    'message' => 'Ein Boolscher Wert, der anzeigt, ob dieses Feld vom Typ __fieldType__ ist. Der erste Buchstabe von __fieldType__ ist immer ein Großbuchstabe. Beispiel: bei einer Auswahlbox ist der Wert von <tmpl_var searchFields_isSelectBox> wahr.'
  },
  'searchFields_label' => {
    'lastUpdated' => '1240495868',
    'message' => 'Die Bezeichnung eines durchsuchbaren Feldes'
  },
  'searchFields_listType' => {
    'lastUpdated' => '1278344653',
    'message' => 'Ein boolscher Wert, der anzeigt, ob diese Feld vom Typ Liste ist.'
  },
  'searchFields_loop' => {
    'lastUpdated' => '1251505193',
    'message' => 'Eine Schleife, die die durchsuchbaren Felder enthält'
  },
  'searchFields_textForm' => {
    'lastUpdated' => '1251505221',
    'message' => 'Texteingabe für die Feldsuche'
  },
  'searchResult_copy_icon' => {
    'lastUpdated' => '1246485169',
    'message' => 'Ein Icon zum Kopieren des Suchergebnisses'
  },
  'searchResult_copy_url' => {
    'lastUpdated' => '1251505253',
    'message' => 'URL um dieses Suchergebnis zu kopieren'
  },
  'searchResult_delete_icon' => {
    'lastUpdated' => '1251505282',
    'message' => 'Lösch-Icon um dieses Suchergebnis zu löschen'
  },
  'searchResult_delete_url' => {
    'lastUpdated' => '1251505298',
    'message' => 'URL um dieses Suchergebnis zu löschen'
  },
  'searchResult_edit_icon' => {
    'lastUpdated' => '1251505810',
    'message' => 'Bearbeitungs-Icon das zur Bearbeiten-Seite dieses Suchergebnis verweist'
  },
  'searchResult_edit_url' => {
    'lastUpdated' => '1251505317',
    'message' => 'URL um dieses Suchergebnis zu bearbeiten'
  },
  'searchResult_field_loop' => {
    'lastUpdated' => '1251505746',
    'message' => 'Eine Schleife, die die Felder enthält, die für dieses Suchergebnis angezeigt werden sollen.'
  },
  'searchResult_id' => {
    'lastUpdated' => '1246485021',
    'message' => 'Die Id eines Suchergebnisses.'
  },
  'searchResult_json' => {
    'lastUpdated' => '1285235293',
    'message' => 'JSON-kodierte Version des searchResult_loop, so dass per JavaScript auf die Daten zugegriffen werden kann.'
  },
  'searchResult_loop' => {
    'lastUpdated' => '1251505702',
    'message' => 'Eine Schleife, die die Suchergebnisse enthält'
  },
  'searchResult_view_url' => {
    'lastUpdated' => '1251505336',
    'message' => 'URL um dieses Suchergebnis anzuzeigen'
  },
  'searchScreenTitle' => {
    'lastUpdated' => '1236680990',
    'message' => 'Suchen'
  },
  'search_url' => {
    'lastUpdated' => '1240487226',
    'message' => 'URL, die zum Suchbildschirm führt.'
  },
  'size description' => {
    'lastUpdated' => '1227000883',
    'message' => 'Einstellung der Größe (Zeichenbreite) der meisten Feldern'
  },
  'size label' => {
    'lastUpdated' => '1227000793',
    'message' => 'Größe'
  },
  'skip label' => {
    'lastUpdated' => '1227000776',
    'message' => 'nicht beachten'
  },
  'sort by label' => {
    'lastUpdated' => '1227000752',
    'message' => 'Sortieren nach'
  },
  'subtext description' => {
    'lastUpdated' => '1240997343',
    'message' => 'Ein Ergänzungstext zum Label unter/nach das Eingabefeld.'
  },
  'subtext label' => {
    'lastUpdated' => '1238256796',
    'message' => 'Zusatztext'
  },
  'template_label' => {
    'lastUpdated' => '1245622894',
    'message' => 'Listenvorlage'
  },
  'thing must have fields' => {
    'lastUpdated' => '1240997415',
    'message' => 'Fehler: Sie sollten Felder für die neue Tabelle definieren.'
  },
  'thing name description' => {
    'lastUpdated' => '1251504962',
    'message' => 'Ein menschenlesbarer Name für für diese Tabelle.'
  },
  'thing name label' => {
    'lastUpdated' => '1240495901',
    'message' => 'Tabellenname'
  },
  'thing_addUrl' => {
    'lastUpdated' => '1251505065',
    'message' => 'Ein Link zur Neu-Seite der Tabelle.'
  },
  'thing_copyIcon' => {
    'lastUpdated' => '1246485061',
    'message' => 'Ein Icon mit einem Link zum Kopieren dieser Tabelle'
  },
  'thing_copyUrl' => {
    'lastUpdated' => '1251505009',
    'message' => 'Ein Link, um diese Tabelle zu kopieren'
  },
  'thing_deleteIcon' => {
    'lastUpdated' => '1246485095',
    'message' => 'Ein Icon mit einem Link zum Löschen dieser Tabelle'
  },
  'thing_deleteUrl' => {
    'lastUpdated' => '1251505035',
    'message' => 'Ein Link, um diese Tabelle zu löschen'
  },
  'thing_editIcon' => {
    'lastUpdated' => '1240496016',
    'message' => 'Ein Icon mit einem Link zum Änderungsbildschirm'
  },
  'thing_editUrl' => {
    'lastUpdated' => '1245622541',
    'message' => 'Ein Link zum Änderungsbildschirm'
  },
  'thing_id' => {
    'lastUpdated' => '1240487143',
    'message' => 'Die ID dieser Tabelle'
  },
  'thing_label' => {
    'lastUpdated' => '1234944794',
    'message' => 'Tabelle'
  },
  'thing_searchUrl' => {
    'lastUpdated' => '1251504988',
    'message' => 'Ein Link zur Suche-Seite dieser Tabelle.'
  },
  'thing_viewIcon' => {
    'lastUpdated' => '1240487037',
    'message' => 'Ein Icon mit einem Link zum Standardbildschirm für diese Tabelle.'
  },
  'things per page description' => {
    'lastUpdated' => '1251505384',
    'message' => 'Anzahl der Things, die pro Suchergebnisseite angezeigt werden'
  },
  'things per page label' => {
    'lastUpdated' => '1240471869',
    'message' => 'Anzahl Tabellen pro Seite'
  },
  'things_loop' => {
    'lastUpdated' => '1251505470',
    'message' => 'Eine Schleife, die die Tabellen und Links zu Bearbeitungsfunktionen enthält, die für dieses Asset definiert sind'
  },
  'thingy asset template variables body' => {
    'lastUpdated' => '1251505669',
    'message' => 'Jedes Asset liefert einen Variablensatz zu den meisten Templates auf Grund der internen Asset-Einstellungen. Manche Variablen sind nützlich, andere evtl. nicht.'
  },
  'thingy asset template variables title' => {
    'lastUpdated' => '1246484966',
    'message' => 'Thingy Asset Vorlagevariabelen'
  },
  'thingy template description' => {
    'lastUpdated' => '1251504906',
    'message' => 'Wählen Sie ein Template für Ihre Tabelle'
  },
  'thingy template label' => {
    'lastUpdated' => '1240471739',
    'message' => 'Tabellenvorlage'
  },
  'vertical description' => {
    'lastUpdated' => '1227000728',
    'message' => 'Diese Eigenschaft bestimmt ob Knöpfe horizontal oder vertikal angezeigt werden.'
  },
  'vertical label' => {
    'lastUpdated' => '1227000570',
    'message' => 'Vertikal'
  },
  'view last edited label' => {
    'lastUpdated' => '1227000599',
    'message' => 'Anzeige letzter Änderung'
  },
  'view screen tab label' => {
    'lastUpdated' => '1240997920',
    'message' => 'Anzeige'
  },
  'view screen title label' => {
    'lastUpdated' => '1240997894',
    'message' => 'Anzeige'
  },
  'view template description' => {
    'lastUpdated' => '1245622812',
    'message' => 'Diese Vorlage wird benutzt für die Ansichtsvorlage zu dieser Tabelle.'
  },
  'view template label' => {
    'lastUpdated' => '1227001612',
    'message' => 'Anzeigevorlage'
  },
  'view thing template label' => {
    'lastUpdated' => '1240495950',
    'message' => 'Vorlage Tabellenanzeige'
  },
  'view thingy default label' => {
    'lastUpdated' => '1227001458',
    'message' => 'Tabelle Standardanzeige'
  },
  'viewScreenTitle' => {
    'lastUpdated' => '1240997967',
    'message' => 'Anzeige'
  },
  'view_url' => {
    'lastUpdated' => '1240471825',
    'message' => 'Die URL, die zur Standardanzeige zurück führt.'
  },
  'who can add description' => {
    'lastUpdated' => '1240487121',
    'message' => 'Die Gruppe, die Daten in diese Tabelle hinzufügen kann.'
  },
  'who can add label' => {
    'lastUpdated' => '1240471773',
    'message' => 'Wer kann hinzufügen?'
  },
  'who can edit description' => {
    'lastUpdated' => '1245622738',
    'message' => 'Selektieren Sie entweder:
- \'Eigentümer\' wenn nur die Person, die dies hinzugefügt hat, Änderungen vornehmen darf,
oder:
- eine Gruppe, die alle Daten dieser Tabelle bearbeiten darf.
Der Benutzer, der dieses Tabelle-Objekt bearbeiten darf, kann immer alles sehen und bearbeiten.'
  },
  'who can edit label' => {
    'lastUpdated' => '1240471838',
    'message' => 'Wer kann bearbeiten?'
  },
  'who can export description' => {
    'lastUpdated' => '1245622767',
    'message' => 'Die Gruppe, die die Daten dieser Tabelle exportieren kann.'
  },
  'who can export label' => {
    'lastUpdated' => '1240471760',
    'message' => 'Wer kann exportieren?'
  },
  'who can import description' => {
    'lastUpdated' => '1245622843',
    'message' => 'Die Gruppe, die Daten zu dieser Tabelle importieren kann.'
  },
  'who can import label' => {
    'lastUpdated' => '1240471719',
    'message' => 'Wer kann importieren?'
  },
  'who can search description' => {
    'lastUpdated' => '1246484993',
    'message' => 'Die Gruppe, die diese Tabelle kann durchsuchen.'
  },
  'who can search label' => {
    'lastUpdated' => '1240471511',
    'message' => 'Wer kann suchen?'
  },
  'who can view description' => {
    'lastUpdated' => '1240486961',
    'message' => 'Selektiere entweder:
- \'owner\' when diese Daten nur von Benutzer, der sie eingetragen hat eingesehen werden dürfen,
oder:
- eine Gruppe, die alle Daten dieser Tabelle sehen darf.
Ein Benutzer, der dieses Thingy ändern darf, kann immer alle Daten sehen und ändern.'
  },
  'who can view label' => {
    'lastUpdated' => '1238879923',
    'message' => 'Wer kann angezeigt bekommen?'
  },
  'width description' => {
    'lastUpdated' => '1227000642',
    'message' => 'Breite von Textfeldern in Pixel'
  },
  'width label' => {
    'lastUpdated' => '1227000610',
    'message' => 'Breite'
  }
}
;

1;
